import ij.IJ;
import ij.Prefs;
import ij.gui.GenericDialog;
import ij.plugin.PlugIn;
import imagescience.utilities.Messenger;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.Panel;

public class FJ_Options implements PlugIn {

    final static String VERSION = "1.3.0";

    static boolean separate = Prefs.get("fj.separate",false);
    static boolean isotropic = Prefs.get("fj.isotropic",false);
    static boolean asksave = Prefs.get("fj.asksave",false);
    static boolean debug = Prefs.get("fj.debug",false);

    public void run(String arg) {

	msg.debug(debug);
	msg.debug("FeatureJ "+FJ_Options.VERSION+": Options");

	if (IJ.versionLessThan("1.35i")) return;

	GenericDialog gd = new GenericDialog("FeatureJ: Options");
	gd.addCheckbox(" Separate smoothing and differentiation    ",separate);
	gd.addCheckbox(" Isotropic Gaussian image smoothing     ",isotropic);
	gd.addCheckbox(" Save result images before closing    ",asksave);
	gd.addCheckbox(" Debug messenging    ",debug);
	gd.addPanel(new Panel(),GridBagConstraints.EAST,new Insets(0,0,0,0));
	gd.showDialog();

	if (gd.wasCanceled()) return;

	separate = gd.getNextBoolean();
	isotropic = gd.getNextBoolean();
	asksave = gd.getNextBoolean();
	debug = gd.getNextBoolean();

	Prefs.set("fj.separate",separate);
	Prefs.set("fj.isotropic",isotropic);
	Prefs.set("fj.asksave",asksave);
	Prefs.set("fj.debug",debug);

	msg.debug(debug);

	if (separate) msg.debug("Separating smoothing and differentiation");
	else msg.debug("Combining smoothing and differentiation");

	if (isotropic) msg.debug("Applying physically isotropic Gaussian smoothing:\nSmoothing scales are divided by aspect-ratio values");
	else msg.debug("Applying not-necessarily-isotropic Gaussian smoothing:\nSmoothing scales are taken in pixel units");

	if (asksave) msg.debug("Asking to save result images before closing");
	else msg.debug("Closing result images without asking to save");

	if (debug) msg.debug("Showing debug messages");
	else msg.debug("Hiding debug messages");
    }

    private final Messenger msg = new Messenger();

}
